pygeodesy.rhumb.aux_

Package pygeodesy :: Package rhumb :: Module aux_ |
[frames] | no frames]

# Module aux_

A pure Python version of Karney's Auxiliary Latitudes, C++ classes Rhumb and RhumbLine from GeographicLib version 2.2+ renamed to RhumbAux respectively RhumbLineAux.

Class RhumbLineAux has been enhanced with methods `Intersecant2`, `Intersection` and `PlumbTo` to iteratively find the intersection of a rhumb line and a circle or an other rhumb line, respectively a perpendicular geodesic or other rhumb line.

For more details, see the GeographicLib 2.2 documentation, especially the Class List, the background information on Rhumb lines, utility RhumbSolve and Online rhumb line calculations.

Copyright (C) Charles Karney (2022-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Notes:

- `S12` area calculations in classes RhumbAux and RhumbLineAux depend on class AuxDST which requires numpy to be installed, version 1.16 or newer.
- Windows reserves file names AUX, COM[#], CON, LPT[#], NUL, PRN with and without extension.

Version: 25.08.31

Classes
| Caps Enum-style masks to be bit-`or`'ed to specify `geodesic`, `rhumb` or `-lines` capabilities (`caps`) and method results (`outmask`).
| RhumbAux Class to solve the direct and inverse rhumb problems, based on Auxiliary Latitudes for accuracy near the poles.
| RhumbLineAux Compute one or several points on a single rhumb line.

Variables
| __all__ = `_ALL_LAZY.rhumb_aux_`